@@ -12,6 +12,7 @@
 
 #include <QObject>
 #include <QVariant>
+#include <QtQmlIntegration>
 #include <memory>
 
 class QQmlEngine;
@@ -42,7 +43,7 @@ class KLocalizedQmlContextPrivate;
  * KLocalization::setupLocalizedContext(&engine);
  * \endcode
  *
- * Then i18n*() and xi18n*() functions should be available for use from the code
+ * Then KI18n.i18n*() and KI18n.xi18n*() functions should be available for use from the code
  * loaded in the engine, for the view.
  *
  * Unlike its predecessor KLocalizedContext this does automatically trigger
@@ -53,8 +54,63 @@ class KLocalizedQmlContextPrivate;
  * real value easily. To solve warnings on those cases we'll cast the first argument
  * to make sure it's taken into account for the plural.
  *
+ * \warning For history reasons the i18n functions are also available on the root context without KI18n.* prefix.
+ * It is very recommended to use the KI18n.* version moving forward, so QML tooling like qmlls and qmllint can inspect
+ * the API calls. KI18n.* was introduced in version 6.21.
+ *
  * \since 6.8
  */
+
+/*!
+    \qmltype KI18n
+    \since 6.21
+    \nativetype KLocalizedQmlContext
+    \inqmlmodule org.kde.ki18n
+    \brief Advanced internationalization support for QML.
+
+    \sa KLocalizedQmlContext::KLocalizedQmlContext()
+
+    To use it, create an instance and set it as the context object of your QML engine in C++:
+
+    \code
+    QQmlApplicationEngine engine;
+    KLocalization::setupLocalizedContext(&engine);
+    \endcode
+
+    Then you can use the KI18n.i18n*() and KI18n.xi18n*() functions from QML code, for example:
+
+    \qml
+    import QtQuick
+    import org.kde.ki18n
+    Text {
+        text: KI18n.i18nc("@label", "Hello World")
+    }
+    \endqml
+*/
+
+/*!
+    \qmltype KI18nContext
+    \since 6.23
+    \nativetype KLocalizedQmlContext
+    \inherits KI18n
+    \inqmlmodule org.kde.ki18n
+    \brief Creatable variant of KI18n
+
+    \sa KI18n
+    \sa KLocalizedQmlContext::KLocalizedQmlContext()
+
+    This is a creatable variant of KI18n and may be used to create multiple localized contexts right from within QML.
+    In particular useful when working with multiple translation domains (such as in library use cases).
+
+    Unlike the KI18n variant this does not require help from the C++ side and can be used entirely from QML:
+
+    \qml
+    readonly property KI18nContext libI18n: KI18nContext {
+        translationDomain: "librocketship"
+    }
+    text: libI18n.i18nc("@title", "Welcome to Space")
+    \endqml
+*/
 class KI18NQML_EXPORT KLocalizedQmlContext : public QObject
 {
     Q_OBJECT
@@ -66,8 +122,16 @@ class KI18NQML_EXPORT KLocalizedQmlContext : public QObject
      * in an application there is no need to set the translation domain as the application's
      * domain can be used.
      */
+    /*!
+        \qmlproperty string KI18nContext::translationDomain
+
+        The translation domain to use for this context. This must be explicitly set for the KI18nContext to be functional.
+    */
     Q_PROPERTY(QString translationDomain READ translationDomain WRITE setTranslationDomain NOTIFY translationDomainChanged)
 
+    QML_ELEMENT
+    QML_NAMED_ELEMENT(KI18nContext)
+
 public:
     /*!
      *
@@ -85,6 +149,12 @@ public:
      */
     void setTranslationDomain(const QString &domain);
 
+    /*!
+        \qmlmethod string KI18n::i18n(message: string, param1: variant = undefined, param2: variant = undefined, param3: variant = undefined, param4: variant =
+            undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined, param8: variant = undefined, param9: variant =
+            undefined, param10: variant = undefined)
+        \sa KLocalizedString::i18n()
+    */
     Q_INVOKABLE QString i18n(const QString &message,
                              const QVariant &param1 = QVariant(),
                              const QVariant &param2 = QVariant(),
@@ -97,6 +167,12 @@ public:
                              const QVariant &param9 = QVariant(),
                              const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::i18nc(context: string, message: string, param1: variant = undefined, param2: variant = undefined, param3: variant = undefined,
+            param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined, param8: variant = undefined,
+            param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::i18nc()
+    */
     Q_INVOKABLE QString i18nc(const QString &context,
                               const QString &message,
                               const QVariant &param1 = QVariant(),
@@ -110,6 +186,12 @@ public:
                               const QVariant &param9 = QVariant(),
                               const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::i18np(singular: string, plural: string, param1: variant = undefined, param2: variant = undefined, param3: variant = undefined,
+            param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined, param8: variant = undefined,
+            param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::i18np()
+    */
     Q_INVOKABLE QString i18np(const QString &singular,
                               const QString &plural,
                               const QVariant &param1 = QVariant(),
@@ -123,6 +205,12 @@ public:
                               const QVariant &param9 = QVariant(),
                               const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::i18ncp(context: string, singular: string, plural: string, param1: variant = undefined, param2: variant = undefined,
+            param3: variant = undefined, param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined,
+            param8: variant = undefined, param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::i18ncp()
+    */
     Q_INVOKABLE QString i18ncp(const QString &context,
                                const QString &singular,
                                const QString &plural,
@@ -137,6 +225,12 @@ public:
                                const QVariant &param9 = QVariant(),
                                const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::i18nd(domain: string, message: string, param1: variant = undefined, param2: variant = undefined, param3: variant = undefined,
+            param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined, param8: variant = undefined,
+            param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::i18nd()
+    */
     Q_INVOKABLE QString i18nd(const QString &domain,
                               const QString &message,
                               const QVariant &param1 = QVariant(),
@@ -150,6 +244,12 @@ public:
                               const QVariant &param9 = QVariant(),
                               const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::i18ndc(domain: string, context: string, message: string, param1: variant = undefined, param2: variant = undefined,
+            param3: variant = undefined, param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined,
+            param8: variant = undefined, param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::i18ndc()
+    */
     Q_INVOKABLE QString i18ndc(const QString &domain,
                                const QString &context,
                                const QString &message,
@@ -164,6 +264,12 @@ public:
                                const QVariant &param9 = QVariant(),
                                const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::i18ndp(domain: string, singular: string, plural: string, param1: variant = undefined, param2: variant = undefined,
+            param3: variant = undefined, param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined,
+            param8: variant = undefined, param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::i18ndp()
+    */
     Q_INVOKABLE QString i18ndp(const QString &domain,
                                const QString &singular,
                                const QString &plural,
@@ -178,6 +284,13 @@ public:
                                const QVariant &param9 = QVariant(),
                                const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::i18ndcp(domain: string, context: string, singular: string, plural: string, param1: variant = undefined,
+            param2: variant = undefined, param3: variant = undefined, param4: variant = undefined, param5: variant = undefined,
+            param6: variant = undefined, param7: variant = undefined, param8: variant = undefined, param9: variant = undefined,
+            param10: variant = undefined)
+        \sa KLocalizedString::i18ndcp()
+    */
     Q_INVOKABLE QString i18ndcp(const QString &domain,
                                 const QString &context,
                                 const QString &singular,
@@ -193,6 +306,12 @@ public:
                                 const QVariant &param9 = QVariant(),
                                 const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::xi18n(message: string, param1: variant = undefined, param2: variant = undefined, param3: variant = undefined, param4: variant =
+            undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined, param8: variant = undefined, param9: variant =
+            undefined, param10: variant = undefined)
+        \sa KLocalizedString::xi18n()
+    */
     Q_INVOKABLE QString xi18n(const QString &message,
                               const QVariant &param1 = QVariant(),
                               const QVariant &param2 = QVariant(),
@@ -205,6 +324,12 @@ public:
                               const QVariant &param9 = QVariant(),
                               const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::xi18nc(context: string, message: string, param1: variant = undefined, param2: variant = undefined, param3: variant = undefined,
+            param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined, param8: variant = undefined,
+            param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::xi18nc()
+    */
     Q_INVOKABLE QString xi18nc(const QString &context,
                                const QString &message,
                                const QVariant &param1 = QVariant(),
@@ -218,6 +343,12 @@ public:
                                const QVariant &param9 = QVariant(),
                                const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::xi18np(singular: string, plural: string, param1: variant = undefined, param2: variant = undefined, param3: variant = undefined,
+            param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined, param8: variant = undefined,
+            param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::xi18np()
+    */
     Q_INVOKABLE QString xi18np(const QString &singular,
                                const QString &plural,
                                const QVariant &param1 = QVariant(),
@@ -231,6 +362,12 @@ public:
                                const QVariant &param9 = QVariant(),
                                const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::xi18ncp(context: string, singular: string, plural: string, param1: variant = undefined, param2: variant = undefined,
+            param3: variant = undefined, param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined,
+            param8: variant = undefined, param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::xi18ncp()
+    */
     Q_INVOKABLE QString xi18ncp(const QString &context,
                                 const QString &singular,
                                 const QString &plural,
@@ -245,6 +382,12 @@ public:
                                 const QVariant &param9 = QVariant(),
                                 const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::xi18nd(domain: string, message: string, param1: variant = undefined, param2: variant = undefined, param3: variant = undefined,
+            param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined, param8: variant = undefined,
+            param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::xi18nd()
+    */
     Q_INVOKABLE QString xi18nd(const QString &domain,
                                const QString &message,
                                const QVariant &param1 = QVariant(),
@@ -258,6 +401,12 @@ public:
                                const QVariant &param9 = QVariant(),
                                const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::xi18ndc(domain: string, context: string, message: string, param1: variant = undefined, param2: variant = undefined,
+            param3: variant = undefined, param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined,
+            param8: variant = undefined, param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::xi18ndc()
+    */
     Q_INVOKABLE QString xi18ndc(const QString &domain,
                                 const QString &context,
                                 const QString &message,
@@ -272,6 +421,12 @@ public:
                                 const QVariant &param9 = QVariant(),
                                 const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::xi18ndp(domain: string, singular: string, plural: string, param1: variant = undefined, param2: variant = undefined,
+            param3: variant = undefined, param4: variant = undefined, param5: variant = undefined, param6: variant = undefined, param7: variant = undefined,
+            param8: variant = undefined, param9: variant = undefined, param10: variant = undefined)
+        \sa KLocalizedString::xi18ndp()
+    */
     Q_INVOKABLE QString xi18ndp(const QString &domain,
                                 const QString &singular,
                                 const QString &plural,
@@ -286,6 +441,13 @@ public:
                                 const QVariant &param9 = QVariant(),
                                 const QVariant &param10 = QVariant()) const;
 
+    /*!
+        \qmlmethod string KI18n::xi18ndcp(domain: string, context: string, singular: string, plural: string, param1: variant = undefined,
+            param2: variant = undefined, param3: variant = undefined, param4: variant = undefined, param5: variant = undefined,
+            param6: variant = undefined, param7: variant = undefined, param8: variant = undefined, param9: variant = undefined,
+            param10: variant = undefined)
+        \sa KLocalizedString::xi18ndcp()
+    */
     Q_INVOKABLE QString xi18ndcp(const QString &domain,
                                  const QString &context,
                                  const QString &singular,
@@ -305,7 +467,6 @@ Q_SIGNALS:
     void translationDomainChanged(const QString &translationDomain);
 
 private:
-    bool eventFilter(QObject *watched, QEvent *event) override;
     std::unique_ptr<KLocalizedQmlContextPrivate> const d;
 };
 
